<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/ecrire_?lang_cible=gl
// ** ne pas modifier le fichier **

return [

	// A
	'activer_plugin' => 'Activar o módulo',
	'affichage' => 'Presentación',
	'aide_non_disponible' => 'Esta parte da axuda en liña aínda non está dispoñible nesta lingua.',
	'auteur' => 'Autor :',
	'avis_acces_interdit' => 'Acceso prohibido.',
	'avis_article_modifie' => 'Atención, @nom_auteur_modif@ estaba traballando neste artigo hai @date_diff@ minutos',
	'avis_aucun_resultat' => 'Ningún resultado.',
	'avis_base_inaccessible' => 'Non foi posible conectarse coa base de datos @base@.',
	'avis_chemin_invalide_1' => 'A rota que elixiches',
	'avis_chemin_invalide_2' => 'non semella ser válida. Volva á páxina anterior e verifique as informacións introducidas.',
	'avis_connexion_echec_1' => 'A conexión á base de datos non vai.',
	'avis_connexion_echec_2' => 'Volva á páxina anterior, e verifique as informacións introducidas.',
	'avis_connexion_echec_3' => '<b>N.B.</b> En moitos servidores, terá que <b>pedir</b> a activación do seu acceso á base SQL antes de podela usar. Se non dá conectado, verifique ter dado ese paso.',
	'avis_connexion_ldap_echec_1' => 'A conexión ao servidor LDAP fallou.',
	'avis_connexion_ldap_echec_2' => 'Volva á páxina anterior, e verifique as informacións introducidas.',
	'avis_connexion_ldap_echec_3' => 'Como alternativa, non empregue o sistema LDAP para importar redactores.', # MODIF
	'avis_deplacement_rubrique' => 'Atención! Este tema contén @contient_breves@ breve@scb@: se a(s) quere desprazar, confírmeo aquí.',
	'avis_erreur_connexion_mysql' => 'Erro de conexión SQL',
	'avis_espace_interdit' => '<b>Espazo prohibido</b> <div>SPIP xa está instalado.</div>',
	'avis_lecture_noms_bases_1' => 'O programa de instalación non puido ler os nomes das bases de datos instaladas.',
	'avis_lecture_noms_bases_2' => 'Pode que non haxa ningunha base dispoñíbel, ou que a función que lista as bases estea desactivada por motivos de seguridade (caso moi frecuente en moitos provedores de servizos).',
	'avis_lecture_noms_bases_3' => 'Na segunda alternativa, é probábel que unha base co seu nome de identificador poida ser empregada:',
	'avis_non_acces_page' => 'Non tes acceso a esta páxina.',
	'avis_operation_echec' => 'Fallou a operación.',
	'avis_operation_impossible' => 'Operación imposíbel',
	'avis_suppression_base' => 'ATENCIÓN, a supresión dos datos é irreversible',

	// B
	'bouton_acces_ldap' => 'Engadir o acceso a LDAP',
	'bouton_ajouter' => 'Engadir',
	'bouton_annuler' => 'Anular',
	'bouton_demande_publication' => 'Solicitar a publicación deste artigo',
	'bouton_desactive_tout' => 'Desactivar todo',
	'bouton_desinstaller' => 'Desinstalar',
	'bouton_effacer_tout' => 'Borrar TODO',
	'bouton_envoyer_message' => 'Mensaxe definitiva: enviar',
	'bouton_fermer' => 'Cerrar',
	'bouton_mettre_a_jour' => 'Actualizar',
	'bouton_mettre_a_jour_base' => 'Actualizar a base de datos',
	'bouton_modifier' => 'Modificar',
	'bouton_radio_afficher' => 'Mostrar',
	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Aparecer na lista de redactores conectados', # MODIF
	'bouton_radio_envoi_annonces_adresse' => 'Enviar os anuncios ao enderezo:',
	'bouton_radio_envoi_liste_nouveautes' => 'Enviar a lista de novidades',
	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'Non aparecer na lista de redactores que publica', # MODIF
	'bouton_radio_non_envoi_annonces_editoriales' => 'Non enviar as novidades editoriais',
	'bouton_redirection' => 'REDIRECCIÓN',
	'bouton_relancer_installation' => 'Relanzar a instalación',
	'bouton_suivant' => 'Seguinte',
	'bouton_tenter_recuperation' => 'Tentar unha reparación',
	'bouton_test_proxy' => 'Probar o proxy',
	'bouton_vider_cache' => 'Baleirar a memoria caché',

	// C
	'cache_modifiable_webmestre' => 'Este parámetro é modificábel polo webmáster do web.', # MODIF
	'calendrier_synchro' => 'Se usa un programa de axenda compatible <b>iCal</b>, poderá sincronizalo coas informacións deste web.',
	'config_activer_champs' => 'Activar os seguintes campos',
	'config_choix_base_sup' => 'escolla unha base de datos deste servidor',
	'config_erreur_base_sup' => 'SPIP non ten acceso á lista de bases de datos accesibles',
	'config_info_base_sup' => 'Se ten outras bases de datos para consultas a través de SPIP, co seu servidor SQL ou con outro, o formulario seguinte permitiralle declaralas. Se deixa certos campos baleiros, os identificadores de conexión á base de datos principal serán os utilizados.',
	'config_info_base_sup_disponibles' => 'Bases suplementarias xa consultables-interrogables:',
	'config_info_enregistree' => 'A nova configuración foi gardada',
	'config_info_logos' => 'Cada elemento do web pode ter un logo, así como un « logo de substitucion »',
	'config_info_logos_utiliser' => 'Utilizar os logos',
	'config_info_logos_utiliser_non' => 'Non utilizar os logos',
	'config_info_logos_utiliser_survol' => 'Utilizar os logos de substitución',
	'config_info_logos_utiliser_survol_non' => 'Utilizar os logos de substitución',
	'config_info_redirection' => 'En activando esta opción, poderá crear artigos virtuais, simples referencias de artigos publicados noutros web ou fóra de SPIP.',
	'config_redirection' => 'Artigos virtuais',
	'config_titre_base_sup' => 'Declaración dunha base suplementaria',
	'config_titre_base_sup_choix' => 'Escolla unha base de datos suplementaria',
	'connexion_ldap' => 'Conexión :',

	// D
	'date_mot_heures' => 'horas',

	// E
	'email' => 'correo electrónico',
	'email_2' => 'correo electrónico:',
	'en_savoir_plus' => 'Máis información',
	'entree_adresse_annuaire' => 'Enderezo da guía',
	'entree_adresse_email' => 'O seu enderezo de correo-e',
	'entree_base_donnee_1' => 'Enderezo da base de datos',
	'entree_base_donnee_2' => '(Moitas veces este enderezo corresponde ao do teu web, ás veces correspóndese coa mención «localhost», e outras pódese deixar baleiro.)',
	'entree_biographie' => 'Curta biografía en catro verbas.',
	'entree_chemin_acces' => '<b>Introduce</b> o camiño de acceso :',
	'entree_cle_pgp' => 'A túa chave GPG',
	'entree_contenu_rubrique' => '(Contido do tema en poucas palabras.)',
	'entree_identifiants_connexion' => 'O seu identificador de conexión...',
	'entree_informations_connexion_ldap' => 'Escriba neste formulario os datos de conexión á túa guía LDAP.
  Estes datos pódellos facilitar o grupo de xestión do sistema, ou da rede.', # MODIF
	'entree_infos_perso' => 'Quen é?',
	'entree_interieur_rubrique' => 'Dentro do tema:',
	'entree_liens_sites' => '<b>Ligazón de hipertexto</b> (referencia, web para visitar...)',
	'entree_login' => 'O seu identificador',
	'entree_login_connexion_1' => 'O identificador de conexión',
	'entree_login_connexion_2' => '(ás veces é o mesmo login que ten para o acceso por FTP; outras veces pódese deixar baleiro)',
	'entree_mot_passe' => 'A súa chave',
	'entree_mot_passe_1' => 'A chave da conexión',
	'entree_mot_passe_2' => '(ás veces é o mesmo que ten para o acceso por FTP; outras veces pódese deixar baleiro)',
	'entree_nom_fichier' => 'Escrebe o nome do ficheiro @texte_compresse@:',
	'entree_nom_pseudo' => 'O seu nome ou a súa identidade (alcume)',
	'entree_nom_pseudo_1' => '(O seu nome ou a súa identidade, alcume)',
	'entree_nom_site' => 'O nome do teu web',
	'entree_nouveau_passe' => 'Nova chave',
	'entree_passe_ldap' => 'Chave',
	'entree_port_annuaire' => 'O número de porto da guía',
	'entree_signature' => 'Sinatura',
	'entree_titre_obligatoire' => '<b>Título</b> [Obrigado]<br />',
	'entree_url' => 'O enderezo (URL) do teu web',
	'erreur_connect_deja_existant' => 'Xa existe un servidor con ese nome',
	'erreur_nom_connect_incorrect' => 'Este nome de servidor non está autorizado',
	'erreur_plugin_desinstalation_echouee' => 'A desinstalación do módulo fallou. No entanto, pode desactivalo.', # MODIF
	'erreur_plugin_fichier_absent' => 'Ficheiro ausente',
	'erreur_plugin_fichier_def_absent' => 'Ficheiro de definición ausente',
	'erreur_plugin_nom_fonction_interdit' => 'Nome de función prohibido',
	'erreur_plugin_nom_manquant' => 'Falta o nome do módulo',
	'erreur_plugin_prefix_manquant' => 'Espazo de chamada do módulo non definido',
	'erreur_plugin_tag_plugin_absent' => 'Falta o&lt;módulo&gt; no ficheiro de definición',
	'erreur_plugin_version_manquant' => 'Falta a versión do módulo',

	// H
	'htaccess_a_simuler' => 'Aviso: a configuración do seu servidor HTTP non ten conta dos ficheiros @htaccess@. Para poder asegurar unha boa seguridade, cómpre que modifique a configuración neste aspecto, ou ben que as constantes @constantes@ (definibles no ficheiro mes_options.php) teñan como valor  cartafoles fóra de @document_root@.',
	'htaccess_inoperant' => 'o htaccess non funciona',

	// I
	'ical_info1' => 'Esta páxina presenta varios métodos para establecer contactos coas novidades deste web.',
	'ical_info2' => 'Para obter máis detalles sobre todas estas técnicas, non dubide en consultar <a href="@spipnet@">a documentación de SPIP</a>.',
	'ical_info_calendrier' => 'Dous calendarios están á súa disposición. O primeiro e un mapa do web que anuncia todos os artigos publicados. O segundo contén os anuncios editoriais así como as súas últimas mensaxes privadas : estalle reservada gracias a unha chave persoal, que pode modificar en calquera momento anovando a súa chave.',
	'ical_methode_http' => 'Descarga',
	'ical_methode_webcal' => 'Sincronización (webcal://)', # MODIF
	'ical_texte_prive' => 'Este calendario, de uso estrictamente persoal, permítelle informarse da actividade editorial privada deste web (tarefas e citas persoais, artigos e breves propostas...).',
	'ical_texte_public' => 'Este calendario permítelle seguir a actividade pública deste web (artigos e breves publicadas).',
	'ical_texte_rss' => 'Pode sindicar as novidades deste web dentro de calquera lector de ficheiros en formato XML/RSS (Rich Site Summary). Este formato tamén lle permite ler con SPIP as novidades publicadas noutros webs que utilicen un formato de intercambio compatible (webs sindicados).',
	'ical_titre_js' => 'Javascript',
	'ical_titre_mailing' => 'Lista de correo',
	'ical_titre_rss' => 'Ficheiros de afiliación',
	'icone_accueil' => 'Portada',
	'icone_activer_cookie' => 'Activar a cookie de correspondencia',
	'icone_activite' => 'Actividade',
	'icone_admin_plugin' => 'Xestión de módulos',
	'icone_administration' => 'Mantemento',
	'icone_afficher_auteurs' => 'Mostrar o equipo de redacción',
	'icone_afficher_visiteurs' => 'Mostrar as visitas',
	'icone_arret_discussion' => 'Non volver participar nesta discusión',
	'icone_calendrier' => 'Calendario',
	'icone_configuration' => 'Configuración',
	'icone_creer_auteur' => 'Crear un novo membro do equipo de redacción e asocialo con este artigo',
	'icone_creer_mot_cle' => 'Crear unha nova palabra chave e asociala con este artigo',
	'icone_creer_rubrique_2' => 'Crear un novo tema',
	'icone_edition' => 'Edición',
	'icone_ma_langue' => 'O meu idioma',
	'icone_mes_infos' => 'Os meus datos',
	'icone_mes_preferences' => 'As miñas preferencias',
	'icone_modifier_article' => 'Modificar este artigo',
	'icone_modifier_rubrique' => 'Modificar este tema',
	'icone_publication' => 'Publicación',
	'icone_relancer_signataire' => 'Relanzar o signatario',
	'icone_retour' => 'Volver',
	'icone_retour_article' => 'Volver ao artigo',
	'icone_squelette' => 'Esqueletos',
	'icone_suivi_publication' => 'Seguimento da publicación',
	'icone_supprimer_cookie' => 'Borrar a cookie de correspondencia',
	'icone_supprimer_rubrique' => 'Borrar este tema',
	'icone_supprimer_signature' => 'Borrar esta sinatura',
	'icone_valider_signature' => 'Validar a sinatura',
	'image_administrer_rubrique' => 'Podes administrar este tema',
	'impossible_modifier_login_auteur' => 'Impossible de modifier le login.', # MODIF
	'impossible_modifier_pass_auteur' => 'Impossible de modifier le mot de passe.', # MODIF
	'info_1_article' => '1 artigo',
	'info_1_auteur' => '1 autor',
	'info_1_message' => '1 mensaxe',
	'info_1_mot_cle' => '1 palabra clave',
	'info_1_rubrique' => '1 sección',
	'info_1_visiteur' => '1 visitante',
	'info_activer_cookie' => 'Pode activar unha <b>cookie de correspondencia</b>, co cal poderá pasar facilmente do web público ao web privado.',
	'info_admin_etre_webmestre' => 'Concederme os dereitos de administrador',
	'info_admin_je_suis_webmestre' => 'Son o/a <b>webmáster</b>',
	'info_admin_statuer_webmestre' => 'Dar a este administrador dereitos de webmáster', # MODIF
	'info_admin_webmestre' => 'Este administrdor é <b>webmáster</b>', # MODIF
	'info_administrateur' => 'Xestión', # MODIF
	'info_administrateur_1' => 'Xestión', # MODIF
	'info_administrateur_2' => 'do web (<i>úsese con sentidiño</i>)',
	'info_administrateur_site_01' => 'Se pertences ó equipo de xestión,', # MODIF
	'info_administrateur_site_02' => 'preme nesta ligazón',
	'info_administrateurs' => 'Xestión', # MODIF
	'info_administrer_rubrique' => 'Podes administrar este tema',
	'info_adresse' => 'ó enderezo:',
	'info_adresse_url' => 'Enderezo (URL) do web público',
	'info_aide_en_ligne' => 'Axuda en liña do SPIP',
	'info_ajout_image' => 'Cando engada imaxes como documentos adxuntos a un artigo,
  SPIP pode crear, automaticamente, viñetas (miniaturas) das
  imaxes insertas. Esto permite crear automaticamente
  unha galería de imaxes.',
	'info_ajouter_rubrique' => 'Engadir outro tema á administrar:',
	'info_annonce_nouveautes' => 'Anuncio de novidades',
	'info_article' => 'Artigo',
	'info_article_2' => 'Artigos',
	'info_article_a_paraitre' => 'Os artigos con data posterior á da sua publicación',
	'info_articles_02' => 'Artigos',
	'info_articles_2' => 'Artigos',
	'info_articles_auteur' => 'Os artigos desta persoa',
	'info_articles_miens' => 'Meus artigos',
	'info_articles_tous' => 'Todos os artigos',
	'info_articles_trouves' => 'Artigos atopados',
	'info_attente_validation' => 'Os teus artigos en espera de validación',
	'info_aucun_article' => 'Ningún artigo',
	'info_aucun_auteur' => 'Ningún autor',
	'info_aucun_message' => 'Ningunha mensaxe',
	'info_aucun_rubrique' => 'Ningunha sección',
	'info_aujourdhui' => 'hoxe:',
	'info_auteur_gere_toutes_rubriques_2' => 'Je gère <b>toutes les rubriques</b>', # MODIF
	'info_auteurs' => 'O equipo de redacción',
	'info_auteurs_par_tri' => 'Autores @partri@',
	'info_auteurs_trouves' => 'Autores/as atopados',
	'info_authentification_externe' => 'Autentificación externa',
	'info_avertissement' => 'Aviso',
	'info_barre_outils' => 'coa barra de utilidades?',
	'info_base_installee' => 'A estrutura da base de datos foi instalada.',
	'info_chapeau' => 'Cabeceira',
	'info_chapeau_2' => 'Cabeceira:',
	'info_chemin_acces_1' => 'Opcións: <b>Camiño de acceso ao anuario</b>',
	'info_chemin_acces_2' => 'En adiante, terá que configurar a vía de acceso ás informacións na guía. Esta información é indispensable para ler os perfís de redactores gardados na guía.', # MODIF
	'info_chemin_acces_annuaire' => 'Opcións: <b>Camiño de acceso ao anuario</b>',
	'info_choix_base' => 'Terceira etapa:',
	'info_classement_1' => '<sup>o</sup> en @liste@',
	'info_classement_2' => '<sup>a</sup> en @liste@',
	'info_code_acces' => 'Non esquezas os teus códigos de acceso!',
	'info_config_suivi' => 'Se este enderezo corresponde á unha lista de correo, vostede pode indicar aquí abaixo o enderezo co cal os participantes no web se poden inscribir. Este enderezo pode ser un URL (por exemplo a páxina de inscrición á lista via web), ou un enderezo de correo electrónico dotado dun asunto específico (por exemplo: <tt>@adresse_suivi@?subject=subscribirse</tt>):',
	'info_config_suivi_explication' => 'Pode subscribirse á lista de correo deste web. Recibirá entón por correo os anuncios de artigos e de breves propostas para publicación.',
	'info_confirmer_passe' => 'Confirmar a nova chave:',
	'info_conflit_edition_avis_non_sauvegarde' => 'Aviso, os campos seguintes foron modificados por outros. As súas modificacións nestes campos non foron rexistradas.',
	'info_conflit_edition_differences' => 'Diferenzas :',
	'info_conflit_edition_version_enregistree' => 'A versión rexistrada :',
	'info_conflit_edition_votre_version' => 'A súa versión :',
	'info_connexion_base' => 'Proba de conexión coa base de datos',
	'info_connexion_base_donnee' => 'Conexión ás súa base de datos',
	'info_connexion_ldap_ok' => 'Conseguiu conexión LDAP.</b><p> Pode pasar á etapa seguinte.</p>', # MODIF
	'info_connexion_mysql' => 'A súa conexión SQL',
	'info_connexion_ok' => 'Conexión feita.',
	'info_contact' => 'Contacto',
	'info_contenu_articles' => 'Contido dos artigos',
	'info_contributions' => 'Contribucións',
	'info_creation_paragraphe' => '(Para crear parágrafos, simplemente deixe liñas baleiras.)', # MODIF
	'info_creation_rubrique' => 'Antes de poder escribir artigos,<br /> ten que crear, cando menos un tema ou sección.<br />',
	'info_creation_tables' => 'Creación das táboas da base de datos',
	'info_creer_base' => '<b>Crear</b> unha nova base de datos:',
	'info_dans_rubrique' => 'No tema:',
	'info_date_publication_anterieure' => 'Data de redacción anterior:',
	'info_date_referencement' => 'DATA DE REFERENCIA DESTE WEB:',
	'info_derniere_etape' => 'Acabouse!',
	'info_descriptif' => 'Descrición:',
	'info_desinstaller_plugin' => 'elimina os datos e desactiva o plugin',
	'info_discussion_cours' => 'Discusións en proceso',
	'info_ecrire_article' => 'Antes de poder escribir artigos, tes que crear, cando menos un tema ou sección.',
	'info_email_envoi' => 'Enderezo de envío de correo (opcional)',
	'info_email_envoi_txt' => 'Indique aquí o enderezo para lle enviar os correos (por defecto o enderezo destinatario será usado como enderezo de envío) :',
	'info_email_webmestre' => 'Enderezo de correo-e. do/a webmáster (opcional)', # MODIF
	'info_envoi_email_automatique' => 'Envío automático de correos-e.',
	'info_envoyer_maintenant' => 'Enviar agora',
	'info_etape_suivante' => 'Pasar á etapa seguinte',
	'info_etape_suivante_1' => 'Podes pasar á etapa seguinte.',
	'info_etape_suivante_2' => 'Podes pasar á etapa seguinte.',
	'info_exceptions_proxy' => 'Excepción para o proxy',
	'info_exportation_base' => 'exportación da base cara a @archive@',
	'info_facilite_suivi_activite' => 'Para facilitar o seguimento da actividade
  editorial do web, SPIP pode enviar por correo-e., por exemplo
  a unha lista de enderezos do equipo de redacción, avisos das peticións
  de publicación e de validacións dos artigos.', # MODIF
	'info_fichiers_authent' => 'Ficheiros de autenticación «.htpasswd»',
	'info_forums_abo_invites' => 'O seu web dispón de foros para se aboar ; os visitantes están invitados a se rexistrar neles na parte pública do web.', # MODIF
	'info_gauche_admin_tech' => '<b>Esta páxina é unicamente accessible para o equipo de xestión do web.</b><p> Dálle acceso a diferentes funcións de mantemento técnico. Algunhas delas dan lugar a procesos de autenticación específicos, que esixen ter un acceso por FTP ao web.</p>',
	'info_gauche_auteurs' => 'Aquí atoparás a todos os autores do web.
  O seu status indícase coa cor da súa ícona (xestor = verde; redactor = amarela).', # MODIF
	'info_gauche_auteurs_exterieurs' => 'Os colaboradores exteriores, sen acceso ao web, indícanse por unha ícona azul;
  os autores que foron eliminados, por unha papeleira.', # MODIF
	'info_gauche_messagerie' => 'A mensaxería permíteche intercambiar mensaxes entre o equipo de redacción, gardar notas (para o teu uso persoal) ou mostrar os anuncios na páxina de entrada do espazo privado (se estás no equipo de xestión).', # MODIF
	'info_gauche_statistiques_referers' => 'Esta páxina presenta a lista de <i>referentes</i>,
  ou sexa, os enderezos con ligazóns apuntando a este mesmo web, únicamente para onte e para hoxe; esta lista ponse a cero a cada 24 horas.',
	'info_gauche_visiteurs_enregistres' => 'aquí atoparás as visitas rexistradas
  no espazo público do web (foros con rexistro).',
	'info_generation_miniatures_images' => 'Creación de miniaturas das imaxes',
	'info_gerer_trad_objets' => '@objets@ : xestionar as ligazóns de tradución',
	'info_hebergeur_desactiver_envoi_email' => 'Algúns aloxadores desactivan o envío automático de
  correos-e. dende os seus servidores. Nese caso, as seguintes funcionalidades do
  SPIP non estarán dispoñibles.',
	'info_hier' => 'onte:',
	'info_identification_publique' => 'A súa identidade pública...',
	'info_image_process' => 'Probe a seleccionar o mellor método de fabricación de viñetas premendo sobre a imaxe correspondente.',
	'info_image_process2' => '<b>N.B.</b> <i>Se non aparece ningunha imaxe, significa que o servidor que aloxa o web non foi configurado para para usar tales utilidades. Se desexa empregar estas funcións, contacte co responsable técnico e solicítelle as extensións «GD» ou «Imagick».</i>', # MODIF
	'info_images_auto' => 'Imaxes calculadas automaticamente',
	'info_informations_personnelles' => 'Datos persoais',
	'info_inscription_automatique' => 'Rexistro automático de novos redactores', # MODIF
	'info_jeu_caractere' => 'Xogo de caracteres do web',
	'info_jours' => 'días',
	'info_laisser_champs_vides' => 'deixar estes campos baleiros)',
	'info_langues' => 'Idiomas do web',
	'info_ldap_ok' => 'A autentificación LDAP foi instalada.',
	'info_lien_hypertexte' => 'Ligazón de hipertexto:',
	'info_liste_redacteurs_connectes' => 'Lista de redactores conectados', # MODIF
	'info_login_existant' => 'Este identificador xa existe.',
	'info_login_trop_court' => 'Identificador curto de máis.',
	'info_logos' => 'Os logos',
	'info_maximum' => 'máximo:',
	'info_meme_rubrique' => 'Na mesma rúbrica ou sección',
	'info_message_en_redaction' => 'As túas mensaxes en proceso de redacción',
	'info_message_technique' => 'Mensaxe técnica:',
	'info_messagerie_interne' => 'mensaxería interna',
	'info_mise_a_niveau_base' => 'posta ao día da súa base SQL',
	'info_mise_a_niveau_base_2' => '{{Atención!}} Instalou unha versión
  de ficheiros SPIP {anterior} á que tiña instalada
  antes neste web: a súa base de datos pode que se perdese
  e o seu web xa non funcionaró.<br />{{Reinstale os
  ficheiros de SPIP.}}',
	'info_modification_enregistree' => 'O modificación rexistrouse',
	'info_modifier_auteur' => 'Modificar o autor:',
	'info_modifier_rubrique' => 'Modificar o tema:',
	'info_modifier_titre' => 'Modificar: @titre@',
	'info_mon_site_spip' => 'O meu web SPIP',
	'info_moyenne' => 'mediana:',
	'info_multi_cet_article' => 'Lingua deste artigo :',
	'info_multi_langues_choisies' => 'Quere seleccionar despois as linguas dispoñibles dos redactores de seu web.
  As linguas xa utilizadas no seu web (fixadas ao principio) non poden ser desactivadas.', # MODIF
	'info_multi_objets' => '@objets@ : activar o menú de idioma',
	'info_multi_secteurs' => '... soamente para as seccións situadas na raíz ?',
	'info_nb_articles' => '@nb@ artigos',
	'info_nb_auteurs' => '@nb@ autores',
	'info_nb_messages' => '@nb@ mensaxes',
	'info_nb_mots_cles' => '@nb@ palabras-clave',
	'info_nb_rubriques' => '@nb@ seccións',
	'info_nb_visiteurs' => '@nb@ visitantes',
	'info_nom' => 'Nome',
	'info_nom_destinataire' => 'Nome do/a destinatario',
	'info_nom_site' => 'Nome do seu web',
	'info_nombre_articles' => '@nb_articles@ artigos,',
	'info_nombre_rubriques' => '@nb_rubriques@ temas,',
	'info_nombre_sites' => '@nb_sites@ webs,',
	'info_non_deplacer' => 'Non desplazar...',
	'info_non_envoi_annonce_dernieres_nouveautes' => 'SPIP pode enviar, regularmente, o anuncio das
  últimas novidades do web (artigos e breves recentes).',
	'info_non_envoi_liste_nouveautes' => 'Non enviar á lista de novidades',
	'info_non_modifiable' => 'Non se pode modificar',
	'info_non_suppression_mot_cle' => 'Non quero eliminar esta palabra chave.',
	'info_notes' => 'Notas',
	'info_nouvel_article' => 'Novo artigo',
	'info_nouvelle_traduction' => 'Nova tradución :',
	'info_numero_article' => 'ARTIGO NÚMERO:',
	'info_obligatoire_02' => '[Obrigatorio]', # MODIF
	'info_option_accepter_visiteurs' => 'Aceptar a inscrición de visitantes do web público', # MODIF
	'info_option_ne_pas_accepter_visiteurs' => 'Rexeitar a inscrición de visitantes', # MODIF
	'info_options_avancees' => 'OPCIÓNS AVANZADAS',
	'info_ou' => 'ou...',
	'info_page_interdite' => 'Páxina prohibida',
	'info_par_nom' => 'por nome',
	'info_par_nombre_article' => 'por número de artigos',
	'info_par_statut' => 'por estado',
	'info_par_tri' => '’(por @tri@)’',
	'info_passe_trop_court' => 'Chave moi curta.',
	'info_passes_identiques' => 'As dúas chaves non son idénticas.',
	'info_plus_cinq_car' => 'máis de 5 caracteres',
	'info_plus_cinq_car_2' => '(Máis de 5 caracteres)',
	'info_plus_trois_car' => '(Máis de 3 caracteres)',
	'info_popularite' => 'popularidade: @popularite@; visitas: @visites@',
	'info_post_scriptum' => 'Pé do artigo',
	'info_post_scriptum_2' => 'Pé do artigo:',
	'info_pour' => 'para',
	'info_preview_texte' => 'É posíbel previsualizar o web como se todos os artigos e breves (que teñan cando menos o estado de « proposto ») estivesen publicados. Esta posibilidade debe estar aberta só para os administradores, para todos os redactores, ou para calquera ?', # MODIF
	'info_procedez_par_etape' => 'procede etapa por etapa',
	'info_procedure_maj_version' => 'o procedemento da posta ó día ten que ser lanzado a fin
		de adaptar a base de datos á nova versión de SPIP.',
	'info_proxy_ok' => 'Test de proxy logrado.',
	'info_ps' => 'PS.',
	'info_publier' => 'publicar',
	'info_publies' => 'Os teus artigos publicados en liña',
	'info_question_accepter_visiteurs' => 'Se os esqueletos do seu web prevén o rexistro de visitantes sen acceso á parte web privada, active a opción aquí abaixo :', # MODIF
	'info_question_inscription_nouveaux_redacteurs' => 'Aceptará as inscricións de novos redactores
  desde o web público? De aceptalos, os visitantes poderanse rexistrar cun
  formulario automatizado e accederán ao espazo privado para
  propor os seus propios artigos.<blockquote> <i>Trala fase de inscrición,
  os usuarios recibirán un correo electrónico automático
  cos seus códigos de acceso ao web privado. Algúns
  provedores desactivan o envío automático desde os seus servidores:
  nese caso, a inscrición automática é imposible.</i></blockquote>', # MODIF
	'info_racine_site' => 'Raíz do web',
	'info_recharger_page' => 'Recarga a páxina nuns intres.',
	'info_recherche_auteur_zero' => '<b>Ningún resultado para "@cherche_auteur@".',
	'info_recommencer' => 'Volta empezar.',
	'info_redacteur_1' => 'Redactor/a',
	'info_redacteur_2' => 'que teñan acceso ó espazo privado (<i>recomendado</i>)',
	'info_redacteurs' => 'Redacción',
	'info_redaction_en_cours' => 'EN PROCESO DE REDACCIÓN',
	'info_redirection' => 'Redirección',
	'info_refuses' => 'Os teus artigos rexeitados',
	'info_reglage_ldap' => 'Opcións: <b>Axustes da importación LDAP</b>',
	'info_renvoi_article' => '<b>Redirección.</b> Este artigo reenví á páxina:',
	'info_reserve_admin' => 'Só o equipo de xestión pode modificar este enderezo.', # MODIF
	'info_restreindre_rubrique' => 'Restrinxir a xestión ó tema:',
	'info_resultat_recherche' => 'Resultados da procura:',
	'info_rubriques' => 'temas',
	'info_rubriques_02' => 'temas',
	'info_rubriques_trouvees' => 'Temas atopados',
	'info_sans_titre' => 'Sen título',
	'info_selection_chemin_acces' => '<b>Selecciona</b> aquí a vía de acceso á guía:',
	'info_signatures' => 'sinaturas',
	'info_site' => 'Web',
	'info_site_2' => 'web:',
	'info_site_min' => 'web',
	'info_site_reference_2' => 'Web referido/referenciado',
	'info_site_web' => 'WEB:', # MODIF
	'info_sites' => 'sitios',
	'info_sites_lies_mot' => 'Os webs referidos ligados a esta palabra chave',
	'info_sites_proxy' => 'Empregar un proxy',
	'info_sites_trouves' => 'Webs atopados',
	'info_sous_titre' => 'Subtítulo:',
	'info_statut_administrateur' => 'Equipo de xestión', # MODIF
	'info_statut_auteur' => 'Categoría deste autor:',
	'info_statut_auteur_a_confirmer' => 'Inscrición para confirmar',
	'info_statut_auteur_autre' => 'Outro estatuto :',
	'info_statut_redacteur' => 'Redactor/a',
	'info_statut_utilisateurs_1' => 'Categoría por defecto de redactores importados', # MODIF
	'info_statut_utilisateurs_2' => 'Escolla a categoría que han ter as persoas presentes na guía LDAP cando se conecten por primeira vez. Máis tarde poderás trocar este valor caso por caso.', # MODIF
	'info_suivi_activite' => 'Seguimento da actividade editorial',
	'info_surtitre' => 'Sobretítulo:',
	'info_syndication_integrale_1' => 'O seu web propón ficheiros de subscrición (ver « <a href="@url@">@titre@</a> »).',
	'info_syndication_integrale_2' => 'Quere transmitir os seus artigos íntegros, ou non difundir máis ca un resumo dalgúns centos de carácteres ?',
	'info_table_prefix' => 'Pode modificarse o prefixo do nome das táboas da base de datos (iso é imprescindible só cando se quere instalar varios spip na mesma base de datos). Este prefixo debe escribirse unicamente con letras minúsculas e sen acentos nin espazos en branco.',
	'info_taille_maximale_images' => 'SPIP testará o tamaño máximo das imaxes que pode tratar (en millóns de píxels).<br /> As imaxes maiores non serán reducidas.',
	'info_taille_maximale_vignette' => 'Tamaño máximo das viñetas xeradas polo sistema:',
	'info_terminer_installation' => 'Agora podes rematar o proceso de instalación estándar.',
	'info_texte' => 'Texto',
	'info_texte_explicatif' => 'Texto explicativo',
	'info_texte_long' => '(o texto é moi longo: así pois, aparecerá en varias partes que serán recompostas trala validación.)',
	'info_texte_message' => 'Texto da súa mensaxe:', # MODIF
	'info_texte_message_02' => 'Texto da mensaxe',
	'info_titre' => 'Título:',
	'info_total' => 'total:',
	'info_tous_articles_en_redaction' => 'Todo os artigos en proceso de redacción',
	'info_tous_articles_presents' => 'Todos os artigos publicados neste tema',
	'info_tous_articles_refuses' => 'Todos os artigos foron rexeitados',
	'info_tous_les' => 'todos os:',
	'info_tout_site' => 'Todo o web',
	'info_tout_site2' => 'O artigo non foi traducido nesta lingua.',
	'info_tout_site3' => 'O artigo foi traducido nesta lingua, pero as modificacións foron aplicadas polo momento ao artigo de referencia. A tradución debe ser actualizada.',
	'info_tout_site4' => 'O artigo foi traducido nesta lingua e a tradución está actualizada.',
	'info_tout_site5' => 'Artigo orixinal.',
	'info_tout_site6' => '<b>Atención :</b> só os artigos orixinais son amosados.
As traducións son asociadas ao orixinal,
cunha cor que indica o seu estado :',
	'info_traductions' => 'Traducións',
	'info_travail_colaboratif' => 'Traballo de colaboración nos artigos',
	'info_un_article' => 'un artigo,',
	'info_un_site' => 'un web,',
	'info_une_rubrique' => 'un tema,',
	'info_une_rubrique_02' => '1 tema',
	'info_url' => 'URL:',
	'info_url_proxy' => 'URL do proxy',
	'info_url_test_proxy' => 'URL de test',
	'info_urlref' => 'Ligazón de hipertexto :',
	'info_utilisation_spip' => 'Agora podes comezar a usar o sistema de publicación asistida...',
	'info_visites_par_mois' => 'Ordear por mes:',
	'info_visiteur_1' => 'Visitante',
	'info_visiteur_2' => 'do web público',
	'info_visiteurs' => 'Visitantes',
	'info_visiteurs_02' => 'Visitantes do web público',
	'info_webmestre_forces' => 'Os/as webmásters actuais están definidos en <tt>@file_options@</tt>.', # MODIF
	'install_adresse_base_hebergeur' => 'Enderezo da base de datos atribuída polo aloxador',
	'install_connect_ok' => 'A nova base está correctamente declarada co nome do servidor @connect@.',
	'install_echec_annonce' => 'A instalación probabelmente vai pechar ou lanzar un sitio non funcional...',
	'install_extension_mbstring' => 'SPIP non funnciona con :',
	'install_extension_php_obligatoire' => 'SPIP exixe a extensión php :',
	'install_login_base_hebergeur' => 'Login de conexión atribuído polo aloxador',
	'install_nom_base_hebergeur' => 'Nome da base atribuída polo aloxador :',
	'install_pas_table' => 'Base actualemente sen táboas',
	'install_pass_base_hebergeur' => 'Chave de conexión atribuída polo aloxador',
	'install_php_version' => 'Versión de PHP @version@ insuficiente (mínima = @minimum@)',
	'install_select_langue' => 'Selecciona un idioma e preme o botón «seguinte» para comezar co proceso de instalación.',
	'install_select_type_db' => 'Indique o tipo de base de datos :',
	'install_select_type_mysql' => 'MySQL',
	'install_select_type_pg' => 'PostgreSQL',
	'install_select_type_sqlite2' => 'SQLite 2',
	'install_select_type_sqlite3' => 'SQLite 3',
	'install_serveur_hebergeur' => 'Servidor da base de datos atribuída polo aloxador',
	'install_table_prefix_hebergeur' => 'Prefixo de táboa atribuído polo aloxador :',
	'install_tables_base' => 'Táboas da base',
	'install_types_db_connus' => 'SPIP pode utilizar <b>MySQL</b> (o máis maioritario), <b>PostgreSQL</b> e <b>SQLite</b>.', # MODIF
	'install_types_db_connus_avertissement' => 'Atención : certos módulos (plugins) non funcionan senón con MySQL', # MODIF
	'intem_redacteur' => 'redactor/a',
	'intitule_licence' => 'Licenza',
	'item_accepter_inscriptions' => 'Aceptar as inscricións',
	'item_activer_messages_avertissement' => 'Activar as mensaxes de aviso',
	'item_administrateur_2' => 'Equipo de xestión', # MODIF
	'item_afficher_calendrier' => 'Mostrar no calendario',
	'item_autoriser_syndication_integrale' => 'Difundir integramente os artigos nos ficheiros de subscrición',
	'item_choix_administrateurs' => 'o equipo de xestión', # MODIF
	'item_choix_generation_miniature' => 'Crear automaticamente as miniaturas das imaxes.',
	'item_choix_non_generation_miniature' => 'Non crear miniaturas das imaxes.',
	'item_choix_redacteurs' => 'o equipo de redacción',
	'item_choix_visiteurs' => 'as visitas do web público',
	'item_creer_fichiers_authent' => 'Crear os ficheiros «.htpasswd»',
	'item_login' => 'Identificador',
	'item_messagerie_agenda' => 'Activar a mensaxería e a axenda',
	'item_mots_cles_association_articles' => 'ós artigos',
	'item_mots_cles_association_rubriques' => 'ós temas',
	'item_mots_cles_association_sites' => 'aos webs referidos ou afiliados.',
	'item_non' => 'Non',
	'item_non_accepter_inscriptions' => 'Non aceptar as inscricións',
	'item_non_activer_messages_avertissement' => 'Sen mensaxes de aviso',
	'item_non_afficher_calendrier' => 'Non mostrar no calendario',
	'item_non_autoriser_syndication_integrale' => 'Non difundir senón un resumo',
	'item_non_creer_fichiers_authent' => 'Non crear estes ficheiros',
	'item_non_messagerie_agenda' => 'Desactivar a mensaxería e a axenda',
	'item_non_publier_articles' => 'Non publicar os artigos antes da data de publicación fixada.',
	'item_nouvel_auteur' => 'Novo/a autor/a',
	'item_nouvelle_rubrique' => 'Novo tema',
	'item_oui' => 'Sí',
	'item_publier_articles' => 'Publicar os artigos, sen importar a súa data de publicación.',
	'item_reponse_article' => 'Resposta ó artigo',
	'item_visiteur' => 'visitante',

	// J
	'jour_non_connu_nc' => 'non consta',

	// L
	'label_bando_outils' => 'Barra de ferramentas',
	'label_bando_outils_afficher' => 'Presentar as ferramentas',
	'label_bando_outils_masquer' => 'Agochas as ferramentas',
	'label_choix_langue' => 'Seleccione o seu idioma',
	'label_nom_fichier_connect' => 'Indique o nome utilizado polo servidor',
	'label_slogan_site' => 'Lema do sitio',
	'label_taille_ecran' => 'Largura de pantalla', # MODIF
	'label_texte_et_icones_navigation' => 'Menú de navegación',
	'label_texte_et_icones_page' => 'Presentación na páxina',
	'ldap_correspondance' => 'herdanza do campo @champ@',
	'ldap_correspondance_1' => 'Herdanza dos campos LDAP',
	'ldap_correspondance_2' => 'Para cadanseu campo SPIP, indique o nome do campo LDAP correspondente. Deixe baleiro para non os cubrir, separar por espazos ou comas para probar varios campos LDAP.',
	'lien_ajouter_auteur' => 'Engadir autor/a',
	'lien_email' => 'correo-e.',
	'lien_nom_site' => 'NOME DO WEB:',
	'lien_retirer_auteur' => 'Retirar esta persoa',
	'lien_retirer_tous_auteurs' => 'Retirar todos os autores',
	'lien_site' => 'web',
	'lien_tout_deplier' => 'Despregalo todo',
	'lien_tout_replier' => 'Repregalo todo',
	'lien_tout_supprimer' => 'Suprimir todo',
	'lien_trier_nom' => 'Ordear por nome',
	'lien_trier_nombre_articles' => 'Ordear por número de artigos',
	'lien_trier_statut' => 'Ordear por categoría',
	'lien_voir_en_ligne' => 'VER EN LIÑA:',
	'logo_article' => 'LOGO DO ARTIGO', # MODIF
	'logo_auteur' => 'LOGO DESTA PERSOA', # MODIF
	'logo_rubrique' => 'LOGO DO TEMA', # MODIF
	'logo_site' => 'LOGO DESTE WEB', # MODIF
	'logo_standard_rubrique' => 'LOGO ESTANDAR DOS TEMAS', # MODIF
	'logo_survol' => 'LOGO DE INTERCAMBIO', # MODIF

	// M
	'menu_aide_installation_choix_base' => 'Elixe a túa base',
	'module_fichier_langue' => 'Ficheiro de lingua',
	'module_raccourci' => 'Recurso',
	'module_texte_affiche' => 'Texto fixado',
	'module_texte_explicatif' => 'Pode inserir os recursos seguintes dentro dos esqueletos do seu web público. Serán automaticamente traducidos ás diferentes linguas para as que existe un ficheiro de lingua.',
	'module_texte_traduction' => 'O ficheiro de lingua « @module@ » está dispoñible en :',
	'mois_non_connu' => 'descoñecido',

	// N
	'nouvelle_version_spip' => 'A versión @version@ de SPIP está dispoñible', # MODIF

	// O
	'onglet_contenu' => 'Contido',
	'onglet_declarer_une_autre_base' => 'Declarar algunha outra base de datos',
	'onglet_discuter' => 'Discutir',
	'onglet_interactivite' => 'Interactividade',
	'onglet_proprietes' => 'Propiedades',
	'onglet_repartition_actuelle' => 'actualmente',
	'onglet_sous_rubriques' => 'Subseccións',

	// P
	'page_pas_proxy' => 'Esta páxina non debe pasar por un proxy',
	'pas_de_proxy_pour' => 'Segundo a súa necesidade, indique as máquinas ou dominios para os cales este proxy non debe ser aplicado (por exemplo : @exemple@)',
	'plugin_charge_paquet' => 'Carga do paquete @name@',
	'plugin_charger' => 'Descargar',
	'plugin_erreur_charger' => 'erro : resulta imposible cargar @zip@',
	'plugin_erreur_droit1' => 'O cartafol <code>@dest@</code> non é accesible para escritura.',
	'plugin_erreur_droit2' => 'Verifique os dereitos deste cartafol (e crealos (no caso de ser necesario), ou instalar o ficheiros por FTP.',
	'plugin_erreur_zip' => 'echec pclzip : erro @status@',
	'plugin_etat_developpement' => 'en desenvolvemento',
	'plugin_etat_experimental' => 'experimental',
	'plugin_etat_stable' => 'estábel',
	'plugin_etat_test' => 'en test',
	'plugin_impossible_activer' => 'Resulta imposible activar o plugin @plugin@',
	'plugin_info_automatique1' => 'Se quere autorizar a instalación automática de módulos (plugins) :',
	'plugin_info_automatique1_lib' => 'Se desexa autorizar a instalación automática desta biblioteca, vexa :',
	'plugin_info_automatique2' => 'Crear un cartafol <code>@rep@</code> ;',
	'plugin_info_automatique3' => 'verificar que o servidor ten permisos para escribir neste cartafol.',
	'plugin_info_automatique_creer' => 'crear na raíz do web.',
	'plugin_info_automatique_exemples' => 'exemplos :',
	'plugin_info_automatique_ftp' => 'Pode instalar os módulos, por FTP, no cartafol <tt>@rep@</tt>',
	'plugin_info_automatique_lib' => 'Certos módulos necesitan tamén poder descargar no cartafol <code>lib/</code>, que deberá ser creado se for preciso na raíz no web.',
	'plugin_info_automatique_liste' => 'A súa listaxe de módulos :',
	'plugin_info_automatique_liste_officielle' => 'os módulos oficiais',
	'plugin_info_automatique_liste_update' => 'Actualizar as listaxes',
	'plugin_info_automatique_ou' => 'ou...',
	'plugin_info_automatique_select' => 'Seleccione a seguir un módulo : SPIP  descargarao e instalarao no cartafol <code>@rep@</code> ; si o módulo xa existe será actualizado.',
	'plugin_info_plugins_dist_1' => 'As extensións seguintes cárganse e actívanse no cartafol @plugins_dist@.', # MODIF
	'plugin_info_plugins_dist_2' => 'Non son desactivables', # MODIF
	'plugin_info_telecharger' => 'descargar desde @url@ e instalalo no cartafol @rep@',
	'plugin_librairies_installees' => 'Librarías instaladas',
	'plugin_necessite_lib' => 'Este módulo necesita a libraría @lib@',
	'plugin_necessite_plugin' => 'Necesita o plugin @plugin@ na súa version @version@ mínimo.', # MODIF
	'plugin_necessite_spip' => 'Necesita SPIP na súa versión @version@ como mínimo.',
	'plugin_source' => 'fonte: ',
	'plugin_titre_automatique' => 'Instalación automática',
	'plugin_titre_automatique_ajouter' => 'Engadir módulos',
	'plugin_titre_installation' => 'Instalación do módulo @plugin@',
	'plugin_zip_active' => 'Continúe para activalo',
	'plugin_zip_adresse' => 'indique seguidamente o enderezo dun ficheiro zip de módulo para descargar, ou mesmo o enderezo dunha lista de módulos (plugins).',
	'plugin_zip_adresse_champ' => 'Enderezo do módulo ou da listaxe ',
	'plugin_zip_content' => 'contén os ficheiros seguintes (@taille@),<br />listos para instalasr no cartafol <code>@rep@</code>',
	'plugin_zip_installe_finie' => 'O ficheiro @zip@ foi descomprimido e instalado.',
	'plugin_zip_installe_rep_finie' => 'O ficheiro @zip@ foi descomprimido e instalado no cartafol @rep@',
	'plugin_zip_installer' => 'Agora pódeo instalar.',
	'plugin_zip_telecharge' => 'O ficheiro @zip@ foi descargado',
	'plugins_actif_aucun' => 'Non hai ningún módulo activado.',
	'plugins_actif_un' => 'Activouse un módulo.',
	'plugins_actifs' => '@count@ módulos activados.',
	'plugins_actifs_liste' => 'Módulos activos', # MODIF
	'plugins_compte' => '@count@ módulos',
	'plugins_disponible_un' => 'Un módulo dispoñible',
	'plugins_disponibles' => '@count@ módulos dispoñibles.',
	'plugins_erreur' => 'Erro nos módulos : @plugins@',
	'plugins_liste' => 'Lista de módulos',
	'plugins_liste_dist' => 'Extensións', # MODIF
	'plugins_recents' => 'Módulos recentes.',
	'plugins_vue_hierarchie' => 'Xerarquía',
	'plugins_vue_liste' => 'Listaxe',
	'protocole_ldap' => 'Versión do protocolo :',

	// Q
	'queue_executer_maintenant' => 'Executar as tarefas de mantemento',
	'queue_nb_jobs_in_queue' => '@nb@ traballos en agarda', # MODIF
	'queue_next_job_in_nb_sec' => 'Próximo traballo en @nb@ s', # MODIF
	'queue_one_job_in_queue' => '1 traballo en agarda', # MODIF
	'queue_purger_queue' => 'Purgar a lista de traballos', # MODIF
	'queue_titre' => 'Lista de traballos', # MODIF

	// R
	'repertoire_plugins' => 'Repertorio :',
	'required' => '[Obrigatorio]', # MODIF

	// S
	'sans_heure' => 'sen hora',
	'statut_admin_restreint' => '(admin restrinxido)', # MODIF

	// T
	'taille_cache_image' => 'As imaxes calculadas automaticamente por SPIP (viñetas dos documentos, títulos presentados so a forma gráfica, funcións matemáticas en formato TeX...) ocupan no directorio @dir@ un total de @taille@.',
	'taille_cache_octets' => 'O tamaño da caché é actualmente de  @octets@.', # MODIF
	'taille_cache_vide' => 'A caché está baleira',
	'taille_repertoire_cache' => 'Tamaño do directorio de memoria caché',
	'text_article_propose_publication' => 'Artigo proposto para publicación.',
	'texte_acces_ldap_anonyme_1' => 'Algúns servidores LDAP non aceptan ningún acceso anónimo. En tal caso hai que especificar un identificador de acceso inicial para poder procurar informacións na guía. Na meirande parte dos casos poderás deixar os seguintes campos baleiros.',
	'texte_admin_effacer_01' => 'Este comando elimina <i>todo</i> o contido da base de datos,
		incluindo <i>todos</i> os accesos dos equipos de xestión e de redacción.
		Logo de executa.lo, terás que lanzar de novo a instalación do SPIP para crear unha
		nova base e un novo acceso de administración.', # MODIF
	'texte_adresse_annuaire_1' => '(Se a súa guía/directorio foi aloxada na mesma máquina ca este
  web, seguramente será «localhost».)',
	'texte_ajout_auteur' => '@ seguinte autor/a foi engadido ao artigo:',
	'texte_annuaire_ldap_1' => 'Se ten acceso a unha guía (LDAP), pódea empregar para importar
  automaticamente usuarios con SPIP.', # MODIF
	'texte_article_statut' => 'Este artigo está:',
	'texte_article_virtuel' => 'Artigo virtual',
	'texte_article_virtuel_reference' => '<b>Artigo virtual:</b> artigo referido no teu web SPIP,
  mais redirixido cara a outro URL. Para eliminar a redirección, elimina o URL aquí.',
	'texte_aucun_resultat_auteur' => 'Ningún resultado de "@cherche_auteur@"',
	'texte_auteur_messagerie' => 'Este web pode indicar permanentemente a lista de redactores que están conectados nun intre, o que lle permite intercambiar mensaxes en directo (cando a mensaxería habilitada). Pode decidir non aparecer nesta lista (será «invisible» para os demais).', # MODIF
	'texte_auteurs' => 'A AUTORÍA',
	'texte_choix_base_1' => 'Elixe a túa base:',
	'texte_choix_base_2' => 'O servidor SQL contén varias bases de datos.',
	'texte_choix_base_3' => '<b>Seleccione</b> aquí a que lle dese o seu provedor:',
	'texte_choix_table_prefix' => 'Prefixo das táboas :',
	'texte_compte_element' => '@count@ elemento',
	'texte_compte_elements' => '@count@ elementos',
	'texte_conflit_edition_correction' => 'Controle a seguir as diferenzas entre as dúas versións do texto; pode tamén copiar as súas modificacións e volver comezar.',
	'texte_connexion_mysql' => 'Consulte os datos que lle proporcionou o seu aloxador: deberá encontrar aí o servidor de bases de datos do que dispón e os identificadores para conectar con el (claves de conexión).',
	'texte_contenu_article' => '(Contido do artigo en poucas palabras.)',
	'texte_contenu_articles' => 'Dependendo da maquetación adoptada para o seu web, pode decidir
  non empregar certos elementos dos artigos. Use esta lista para indicar cales serán os elementos dispoñibles.',
	'texte_crash_base' => 'Se a base de datos ten algún problema, podes tentar unha reparación automática.',
	'texte_creer_rubrique' => 'Antes de poder escribir artigos<br/>, ten que crear un tema ou sección.',
	'texte_date_creation_article' => 'DATA DE CREACIÓN DO ARTIGO',
	'texte_date_publication_anterieure' => 'Data de redacción anterior :',
	'texte_date_publication_anterieure_nonaffichee' => 'Non mostrar data de redacción anterior.',
	'texte_date_publication_article' => 'DATA DE PUBLICACIÓN EN LIÑA :',
	'texte_descriptif_rapide' => 'Descrición rápida',
	'texte_effacer_base' => 'Eliminar a base de datos SPIP',
	'texte_effacer_statistiques' => 'Borrar as estatísticas',
	'texte_en_cours_validation' => 'Os artigos e as breves de aquí embaixo foron propostos para a súa publicación.', # MODIF
	'texte_enrichir_mise_a_jour' => 'Pódese mellorar a presentación do texto empregando os «atallos tipográficos».',
	'texte_fichier_authent' => '<b>SPIP ten que crear os ficheiros especiais <tt>.htpasswd</tt>
  e <tt>.htpasswd-admin</tt> no cartafol @dossier@?</b><p>
  Estes ficheiros pódenlle servir para restrinxir o acceso, tanto aos autores
  coma aos administradores a outras partes do seu web (ao programa
  externo de estatísticas, por exemplo).</p><p>
  Se non o utiliza, pode deixar esta opción
 co seu valor predeterminado (non crear
estes ficheiros).</p>', # MODIF
	'texte_informations_personnelles_1' => 'O sistema vaiche crear agora un acceso personalizado ao web',
	'texte_informations_personnelles_2' => '(Nota: se se trata dunha reinstalación, e o teu acceso vai sen atrancos, podes', # MODIF
	'texte_introductif_article' => '(Texto introdutorio do artigo.)',
	'texte_jeu_caractere' => 'Aconséllase empregar, no seu web, o alfabeto universal (<tt>utf-8</tt>) : isto permite mostrar textos en todas as linguas, e non presenta problemas de compatibilidade cos navegadores modernos.',
	'texte_jeu_caractere_3' => 'O seu web está actualmente instalado co xogo de carácteres :',
	'texte_jeu_caractere_4' => 'Se iso non corresponde coa realidade dos seus datos (logo, por exemplo, dunha restauración da base de datos), ou se <em>vostede principia neste web</em> e quere partir doutro xogo de carácteres, indíqueo por favor aquí :',
	'texte_login_ldap_1' => '(Deixar baleiro para un acceso anónimo, ou poñer a vía completa,
  por exemplo «<tt>uid=maricarmen, ou=users, dc=meu-dominio, dc=com</tt>».)',
	'texte_login_precaution' => 'Atención! Este é o identificador co que se conectou.
  Empregue este formulario con precaución...',
	'texte_messagerie_agenda' => 'A mensaxería permítelles aos redactores do web comunicarse entre eles directamente no espazo privado do web. Está asociado a unha axenda.', # MODIF
	'texte_mise_a_niveau_base_1' => 'Acaba de por ao día os ficheiros do SPIP.
  Agora ten que actualizar a base de datos do web.',
	'texte_modifier_article' => 'Modificar o artigo:',
	'texte_multilinguisme' => 'Se desexa crear artigos en varias linguas, cunha navegación complexa, pode engadir un menú de selección da lingua dos artigos e/ou das seccións, en función da organización do seu web.', # MODIF
	'texte_multilinguisme_trad' => 'Pode igualmente activar un sistema de xestión de ligazóns entre as diferentes traducións dun artigo.', # MODIF
	'texte_non_compresse' => '<i>non comprimido</i> (o teu servidor non soporta esta funcionalidade)',
	'texte_nouvelle_version_spip_1' => 'Instalaches unha nova versión de SPIP.',
	'texte_nouvelle_version_spip_2' => 'Esta nova versión precisa unha posta ao día máis completa que a habitual. De seres webmáster do web, elimine o ficheiro @connect@ e retome a instalación para poñer ao día os parámetros de conexión á base de datos.<p> (NB. : se esqueceu os parámetros de conexión, bótelle un ollo ao ficheiro  @connect@ antes de borralo...)</p>',
	'texte_operation_echec' => 'Volve á páxina anterior, selecciona outra base ou crea unha nova. Verifica a información que che dera o teu aloxador.',
	'texte_plus_trois_car' => 'máis de 3 caracteres',
	'texte_plusieurs_articles' => 'Atopáron.se varias entradas para "@cherche_auteur@":',
	'texte_port_annuaire' => '(En xeral, convén poñer o valor indicado por defecto.)',
	'texte_presente_plugin' => 'Esta páxina lista os módulos dispoñibles no web. Pode activar os módulos necesarios marcando a caixa correspondente.',
	'texte_proposer_publication' => 'Cando remate o seu artigo,<br />pode propor que sexa publicado.',
	'texte_proxy' => 'Nalgúns casos (intranet, redes protexidas...), os webs distantes (documentación de SPIP, webs afiliados, etc. ) non son accesibles se non é por medio dun <i>proxy HTTP</i>. Chegado o caso, indique aquí embaixo o seu enderezo, no formato @proxy_en_cours@.
  En xeral, deixará; esta caixa baleira.',
	'texte_publication_articles_post_dates' => 'Que comportamento debe adoptar o SPIP cos artigos nos
  que a data de publicación foi fixada no futuro?',
	'texte_rappel_selection_champs' => '[Lembre seleccionar correctamente este campo.]',
	'texte_recalcul_page' => 'Se quere recalcular unha soa páxina, vaia millor polo espazo público e empregue o botón «recargar».',
	'texte_recuperer_base' => 'Reparar a base de datos',
	'texte_reference_mais_redirige' => 'artigo referido no seu web SPIP, mais redirixido cara a outro URL.',
	'texte_requetes_echouent' => '<b>Cando algunhas peticións SQL fallan
 sistematicamente e sen razón aparente, é posible
 que a causa sexa a propia base de datos.
</b><p>
  SQL ten unha opción de reparación das
 táboas cando estas foron danadas por accidente.
  Aí pode tentar esta reparación; en caso de fallo, garde unha copia do resultado, que pode que conteña indicios do que non vai ben...<p>
  Se o problema persiste, póñase en contacto co seu provedor de aloxamento.<p>',
	'texte_selection_langue_principale' => 'Pode seleccionar aquí embaixo a «lingua principal» do web. Esta elección non obriga (malo sería!) a escribir os artigos no idioma seleccionado, mais permite determinar:
  <ul><li>o formato por defecto das datas no web público;</li>
  <li>a natureza do motor tipográfico que SPIP ten que empregar para a reprodución dos textos;</li>
  <li>a lingua empregada nos formularios do web público;</li>
  <li>a lingua presentada por defecto no espazo privado.</li></ul>',
	'texte_sous_titre' => 'Subtítulo',
	'texte_statistiques_visites' => '(barras escuras:  domingo / curva escura: evolución da media)',
	'texte_statut_attente_validation' => 'agardando pola validación',
	'texte_statut_publies' => 'publicados en liña',
	'texte_statut_refuses' => 'rexeitados',
	'texte_suppression_fichiers' => 'Empregue este comando para suprimir todos os ficheiros presentes
  na caché do Spip. Isto permite, por exemplo, forzar un novo cálculo de todas as páxinas cando se fagan
  grandes cambios gráficos ou de estrutura do web.',
	'texte_sur_titre' => 'Sobretítulo',
	'texte_table_ok' => ': esta táboa está ben.',
	'texte_tentative_recuperation' => 'Tentativa de reparación',
	'texte_tenter_reparation' => 'Tentar unha reparación da base de datos',
	'texte_test_proxy' => 'Para probar o proxy, indique o enderezo do web que queira testear.',
	'texte_titre_02' => 'Título:',
	'texte_titre_obligatoire' => '<b>Título</b> [Obrigado]',
	'texte_travail_article' => '@nom_auteur_modif@ traballou neste artigo hai @date_diff@ minutos',
	'texte_travail_collaboratif' => 'Se é habitual que varias persoas traballen nun
  artigo ao mesmo tempo, o sistema pode mostrar os artigos 
  «abertos» recentemente, por mor de evitar as 
  modificacións simultáneas. Esta opción está 
  desactivada por defecto para evitar mostrar mensaxes de aviso intempestivas.', # MODIF
	'texte_vide' => 'baleiro',
	'texte_vider_cache' => 'Baleirar a memoria caché',
	'titre_admin_tech' => 'Mantemento técnico',
	'titre_ajouter_un_auteur' => 'Engadir un autor',
	'titre_ajouter_un_mot' => 'Engadir unha palabra-clave',
	'titre_cadre_afficher_article' => 'Mostrar os artigos',
	'titre_cadre_afficher_traductions' => 'Fixar o estado das traducións para as seguintes linguas :',
	'titre_cadre_ajouter_auteur' => 'ENGADIR UN/UNHA AUTOR/A:',
	'titre_cadre_interieur_rubrique' => 'Dentro do tema',
	'titre_cadre_numero_auteur' => 'AUTOR/A NÚMERO',
	'titre_cadre_numero_objet' => '@objet@ NUMÉRO :',
	'titre_cadre_signature_obligatoire' => '<b>Sinatura</b> [Obrigado]<br />',
	'titre_config_contenu_notifications' => 'Notificacións',
	'titre_config_contenu_prive' => 'No espazo privado',
	'titre_config_contenu_public' => 'No web público',
	'titre_config_fonctions' => 'Configuración do web',
	'titre_config_langage' => 'Configurar o idioma',
	'titre_configuration' => 'Configuración do web',
	'titre_configurer_preferences' => 'Configurar as súas preferencias',
	'titre_conflit_edition' => 'Conflito tras a edición',
	'titre_connexion_ldap' => 'Opcións: <b>A súa conexión LDAP</b>',
	'titre_groupe_mots' => 'GRUPO DE PALABRAS:',
	'titre_identite_site' => 'Identidade do sitio',
	'titre_langue_article' => 'LINGUA DO ARTIGO', # MODIF
	'titre_langue_rubrique' => 'LINGUA DA SECCIÓN', # MODIF
	'titre_langue_trad_article' => 'LINGUA E TRADUCIÓNS DO ARTIGO',
	'titre_les_articles' => 'OS ARTIGOS',
	'titre_messagerie_agenda' => 'Mensaxería e axenda',
	'titre_naviguer_dans_le_site' => 'Navegar no web...',
	'titre_nouvelle_rubrique' => 'Novo tema',
	'titre_numero_rubrique' => 'TEMA NÚMERO:',
	'titre_page_articles_edit' => 'Modificar: @titre@',
	'titre_page_articles_page' => 'Os artigos',
	'titre_page_articles_tous' => 'Todo o web',
	'titre_page_calendrier' => 'Calendario @nom_mois@ @annee@',
	'titre_page_config_contenu' => 'Configuración do web',
	'titre_page_delete_all' => 'Supresión total e irreversible',
	'titre_page_recherche' => 'Resultados da procura de @recherche@',
	'titre_page_statistiques_referers' => 'Estatísticas (ligazóns entrantes)',
	'titre_page_upgrade' => 'Posta ao día de SPIP',
	'titre_publication_articles_post_dates' => 'Publicación dos artigos con data posterior',
	'titre_reparation' => 'Reparación',
	'titre_suivi_petition' => 'Seguimento das peticións',
	'tls_ldap' => 'Capa de seguridade de transporte (Transport Layer Security) :',
	'trad_article_traduction' => 'Todas as versións deste artigo :',
	'trad_delier' => 'Non ligar a estas traducións',
	'trad_lier' => 'Este artigo é unha tradución do artigo número :',
	'trad_new' => 'Escribir unha nova tradución',

	// U
	'utf8_convert_erreur_orig' => 'Erro : o xogo de carácteres @charset@ non está soportado.',

	// V
	'version' => 'Versión :',
];
